@@ -5,6 +5,8 @@
 #include <stdexcept>
 #include <qpdf/QPDFWriter.hh>
 #include <qpdf/QUtil.hh>
+#include <qpdf/QPDFPageDocumentHelper.hh>
+#include <qpdf/QPDFAcroFormDocumentHelper.hh>
 #include "qpdf_tools.h"
 #include "qpdf_xobject.h"
 #include "qpdf_pdftopdf.h"
@@ -379,7 +381,7 @@ void QPDF_PDFTOPDF_Processor::error(const char *fmt,...) // {{{
 
 // TODO?  try/catch for PDF parsing errors?
 
-bool QPDF_PDFTOPDF_Processor::loadFile(FILE *f,ArgOwnership take) // {{{
+bool QPDF_PDFTOPDF_Processor::loadFile(FILE *f,ArgOwnership take,int flatten_forms) // {{{
 {
   closeFile();
   if (!f) {
@@ -414,12 +416,12 @@ bool QPDF_PDFTOPDF_Processor::loadFile(FILE *f,ArgOwnership take) // {{{
     error("loadFile with MustDuplicate is not supported");
     return false;
   }
-  start();
+  start(flatten_forms);
   return true;
 }
 // }}}
 
-bool QPDF_PDFTOPDF_Processor::loadFilename(const char *name) // {{{
+bool QPDF_PDFTOPDF_Processor::loadFilename(const char *name,int flatten_forms) // {{{
 {
   closeFile();
   try {
@@ -429,15 +431,23 @@ bool QPDF_PDFTOPDF_Processor::loadFilename(const char *name) // {{{
     error("loadFilename failed: %s",e.what());
     return false;
   }
-  start();
+  start(flatten_forms);
   return true;
 }
 // }}}
 
-void QPDF_PDFTOPDF_Processor::start() // {{{
+void QPDF_PDFTOPDF_Processor::start(int flatten_forms) // {{{
 {
   assert(pdf);
 
+  if (flatten_forms) {
+    QPDFAcroFormDocumentHelper afdh(*pdf);
+    afdh.generateAppearancesIfNeeded();
+
+    QPDFPageDocumentHelper dh(*pdf);
+    dh.flattenAnnotations(an_print);
+  }
+
   pdf->pushInheritedAttributesToPage();
   orig_pages=pdf->getAllPages();
 
@@ -648,3 +658,16 @@ void QPDF_PDFTOPDF_Processor::emitFilename(const char *name) // {{{
 
 // TODO:
 //   loadPDF();   success?
+
+bool QPDF_PDFTOPDF_Processor::hasAcroForm() // {{{
+{
+  if (!pdf) {
+    return false;
+  }
+  QPDFObjectHandle root=pdf->getRoot();
+  if (!root.hasKey("/AcroForm")) {
+    return false;
+  }
+  return true;
+}
+// }}}
