@@ -34,8 +34,8 @@ class QPDF_PDFTOPDF_PageHandle : public PDFTOPDF_PageHandle {
 
 class QPDF_PDFTOPDF_Processor : public PDFTOPDF_Processor {
  public:
-  virtual bool loadFile(FILE *f,ArgOwnership take=WillStayAlive);
-  virtual bool loadFilename(const char *name);
+  virtual bool loadFile(FILE *f,ArgOwnership take=WillStayAlive,int flatten_forms=1);
+  virtual bool loadFilename(const char *name,int flatten_forms=1);
 
   // TODO: virtual bool may_modify/may_print/?
   virtual bool check_print_permissions();
@@ -61,7 +61,7 @@ class QPDF_PDFTOPDF_Processor : public PDFTOPDF_Processor {
  private:
   void closeFile();
   void error(const char *fmt,...);
-  void start();
+  void start(int flatten_forms);
  private:
   std::unique_ptr<QPDF> pdf;
   std::vector<QPDFObjectHandle> orig_pages;
